## Afiliepy

Replace other users affiliate link to own one.  

## Instration  

```
pip install affilipy
```

## Usage  

```
import affilipy

from affilipy import affilipy

affilipy.replace('amazon', 'https://amzn.to/...', your_key)
#=> https://www.amazon.co.jp/gp/product/...?tag={your_key}
```
